@@ -30,6 +30,7 @@ COVERAGE_REPORT_HTML_OUTPUT_DIR = os.path.join(
 COVERAGE_MODULE_EXCLUDES = [
     'tests$', 'settings$', 'urls$', 'locale$',
     'migrations', 'fixtures', 'admin$', 'django_extensions',
+    'testrunner',
 ]
 
 EXTERNAL_APPS = [
@@ -55,3 +56,7 @@ INSTALLED_APPS = EXTERNAL_APPS + INTERNAL_APPS
 COVERAGE_MODULE_EXCLUDES += EXTERNAL_APPS
 
 TEST_LOAD_MEMBER = 'django_libs.loaders.load_member'
+
+AUTH_PROFILE_MODULE = 'test_app.DummyProfile'
+
+ANALYTICS_TRACKING_ID = 'UA-THISISNOREAL-ID'
